import logging

class ImageSearch:
    __logger = logging.getLogger(__name__)

    def __init__(self, feature_extractor, milvus):
        self.feature_extractor = feature_extractor
        self.milvus = milvus

    # id = product_id
    def image_to_image_search(self, bucket, image, top_k = 100):
        try:
            # 提取查询图像的特征
            vector = self.feature_extractor.extract_features(image)

            # anns_field = embedding
            # output_fields=["image", "product_id"]
            # search_params: Dict[str, Any] = {"metric_type": "IP", "params": {"ef": 100}}

            results = self.milvus.search(bucket, vector, top_k)

            # 处理结果
            if not results or len(results) == 0:
                return []

            # 返回结果
            keys = [hit.entity.get("key") for hit in results[0]]
            scores = [hit.score for hit in results[0]]

            return list(zip(keys, scores))

        except Exception as e:
            self.__logger.error(f"Image search failed: {e}")
            raise ValueError(f"Image search failed: {e}")